@@ -40,8 +40,10 @@ import os
 import sys
 import xmlrpclib
 import copy
-import logging, logging.handlers
-from copy import deepcopy, copy
+import logging
+import logging.handlers
+from copy import copy
+from copy import deepcopy
 from optparse import OptionParser
 import exceptions
 import unicode_csv
@@ -109,69 +111,66 @@ def connect(host=HOST, port=PORT, user=USER, pwd=PWD, dbname=DB):
 class Import(object):
     """Main class which provides the functionnal part of the importation process
     
-    .. note::
-    
-        `sys.argv` is integrated if you want to use the command line parser.
+    .. note:: `sys.argv` is integrated if you want to use the command line parser.
 
     Here are the available command line arguments::
 
-        -h, --help                  show this kind of help message and exit
+        -h, --help                  Show this kind of help message and exit
         -o OFFSET, --offset=OFFSET  Offset (Usually for header omission)
         -l LIMIT, --limit=LIMIT     Limit
         -c, --check-mapping         Check mapping template
-        -v, --verbose               verbose mode
+        -v, --verbose               Verbose mode
         -d, --debug      
            debug mode
-        -q, --quiet                 don't print anything to stdout
+        -q, --quiet                 Doesn't print anything to stdout
 
     """
 
     @property
     def server(self):
-        """ Return the current socket connection to the OpenERP server (xml-rpc)
-        of this session.
+        """ Return the current socket connection to the OpenERP server (xmlrpc).
 
         """
         return self._server
 
     @property
     def host(self):
-        """ Return the current connection host of this session.
+        """ Return the current connection host for this session.
 
         """
         return self._host
 
     @property
     def port(self):
-        """ Return the current connection port of this session.
+        """ Return the current connection port for this session.
 
         """
         return self._port
 
     @property
     def db(self):
-        """ Return the current database name of this session.
+        """ Return the current database name for this session.
 
         """
         return self._db
 
     @property
     def user(self):
-        """ Return the current username of this session.
+        """ Return the current username for this session.
 
         """
         return self._user
 
     @property
     def uid(self):
-        """ Return the current UID of this session. Mandatory for a self.server call
+        """ Return the current UID for this session.
 
         """
         return self._uid
 
     @property
     def pwd(self):
-        """ Return the current password of this session
+        """ Return the current password for this session
 
         """
         return self._pwd
@@ -180,7 +179,7 @@ class Import(object):
     def lines(self):
         """Getting all lines from CSV parser
         
-        :returns: list of lines (already a list)
+        :returns: list
 
         """
         return self._lines
@@ -286,13 +285,16 @@ class Import(object):
         self._db = self.options.dbname
         self._user = self.options.username
         self._pwd = self.options.password
-
+        return 
 
     #===========================================================================
     # SETTER
     #===========================================================================
     def connect(self, host=HOST, port=PORT, user=USER, pwd=PWD, dbname=DB):
-        """Set nistance's contants needed to initialize a connection to openerp
+        """Declare a new connection to an OpenERP instance.
+        
+        .. note:: Needed if several CSV files acts in differents OpenERP
+        servers. Otherwise, please use the ``csv2oerp.connect`` function
 
         :param host: IP or DNS name of the OERP server
         :type host: str
@@ -304,20 +306,25 @@ class Import(object):
         :type pwd: str
         :param dbname: Name of the database to reach
         :type dbname: str
-        :raises: nothing
+        :returns: bool
+
         """
         self._host = host
         self._port = port
         self._user = user
         self._pwd = pwd
         self._db = dbname
+        return True
 
     def set_logger(self, name=None):
         """Configure and initialize the logger facility
 
+        .. note:: Optionnal
+
         :param name: Name of the logger
         :type name: str
-        :raises: 
+        :returns: bool
+        
         """
         global STATS, FORMAT
         try:
@@ -351,6 +358,7 @@ class Import(object):
                 logging.basicConfig(format=FORMAT) # console log
     
         self._logger.info("Logger set to '%s'" % basename, extra=STATS)
+        return True
 
     def _is_model(self, model):
         """Check model validity
@@ -380,11 +388,9 @@ class Import(object):
         return False
 
     def _check_mapping(self, mapping):
-        """Check mapping fro semantic errors
+        """Check mapping for semantics errors
 
-         .. note::
-        
-            Also start the logger and initialize the connection to OpenERP
+         .. note:: Also setup the logger and initialize OpenERP connection
 
         """
         #======================================================================
@@ -457,7 +463,7 @@ formed, \n\n" % (model, attr)
             
     def set_input_file(self, filename, delimiter=',', quotechar='"',
             encoding='utf8'):
-        """Set the CSV file to use.
+        """Set the CSV file to use for importation.
 
         """
         global STATS
@@ -487,9 +493,11 @@ formed, \n\n" % (model, attr)
         :param dbname: Name of the database to reach
         :type dbname: str
         :raises: nothing
+        
+        .. versionadded:: 0.5.1
 
         """
-        raise NotImplemented
+        return NotImplemented
 
     def set_preconfigure_script(self, filename):
         """Declare a parrallel script which will be called before importation.
